@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 # Copyright (c) 2010-2019 openpyxl
 
 
@@ -6,7 +5,6 @@ from .cell import (
     absolute_coordinate,
     cols_from_range,
     column_index_from_string,
-    coordinate_from_string,
     coordinate_to_tuple,
     get_column_letter,
     get_column_interval,
