@@ -1,11 +1,8 @@
-from __future__ import absolute_import
 # Copyright (c) 2010-2019 openpyxl
 
 import re
 import warnings
 
-from openpyxl.compat import unicode, safe_repr
-
 from openpyxl.worksheet.header_footer import HeaderFooter
 
 """
@@ -42,27 +39,27 @@ class _WorkbookChild(object):
     __title = ""
     _id = None
     _path = "{0}"
-    __parent = None
+    _parent = None
     _default_title = "Sheet"
 
     def __init__(self, parent=None, title=None):
-        self.__parent = parent
+        self._parent = parent
         self.title = title or self._default_title
         self.HeaderFooter = HeaderFooter()
 
 
     def __repr__(self):
-        return '<{0} "{1}">'.format(self.__class__.__name__, safe_repr(self.title))
+        return '<{0} "{1}">'.format(self.__class__.__name__, self.title)
 
 
     @property
     def parent(self):
-        return self.__parent
+        return self._parent
 
 
     @property
     def encoding(self):
-        return self.__parent.encoding
+        return self._parent.encoding
 
 
     @property
@@ -77,18 +74,18 @@ class _WorkbookChild(object):
         Limited to 31 characters, no special characters.
         Duplicate titles will be incremented numerically
         """
-        if not self.__parent:
+        if not self._parent:
             return
 
         if not value:
             raise ValueError("Title must have at least one character")
 
         if hasattr(value, "decode"):
-            if not isinstance(value, unicode):
+            if not isinstance(value, str):
                 try:
                     value = value.decode("ascii")
                 except UnicodeDecodeError:
-                    raise ValueError("Worksheet titles must be unicode")
+                    raise ValueError("Worksheet titles must be str")
 
         m = INVALID_TITLE_REGEX.search(value)
         if m:
